@@ -41,8 +41,6 @@
 #' @param sample.size.label Logical that decides whether sample size information
 #'   should be displayed for each level of the grouping variable `x` (Default:
 #'   `TRUE`).
-#' @param mean.label.size,mean.label.fontface,mean.label.color Aesthetics for
-#' the label displaying mean. Defaults: `3`, `"bold"`,`"black"`, respectively.
 #' @param notch A logical. If `FALSE` (default), a standard box plot will be
 #'   displayed. If `TRUE`, a notched box plot will be used. Notches are used to
 #'   compare groups; if the notches of two boxes do not overlap, this suggests
@@ -64,8 +62,9 @@
 #'   `outlier.shape = NA`. Importantly, this does not remove the outliers,
 #'   it only hides them, so the range calculated for the `y`-axis will be
 #'   the same with outliers shown and outliers hidden.
-#' @param outlier.label.color Color for the label to to put on the outliers that
-#'   have been tagged (Default: `"black"`).
+#' @param outlier.point.args,outlier.label.args A list of additional aesthetic arguments to be
+#'   passed to `ggplot2::geom_point` and `ggrepel::geom_label_repel` geoms
+#'   involved outlier value plotting.
 #' @param outlier.coef Coefficient for outlier detection using Tukey's method.
 #'   With Tukey's method, outliers are below (1st Quartile) or above (3rd
 #'   Quartile) `outlier.coef` times the Inter-Quartile Range (IQR) (Default:
@@ -74,45 +73,33 @@
 #'   and its value to be displayed (Default: `TRUE`).
 #' @param mean.ci Logical that decides whether `95%` confidence interval for
 #'   mean is to be displayed (Default: `FALSE`).
-#' @param mean.color Color for the data point corresponding to mean (Default:
-#'   `"darkred"`).
-#' @param mean.size Point size for the data point corresponding to mean
-#'   (Default: `5`).
 #' @param palette If a character string (e.g., `"Set1"`), will use that named
 #'   palette. If a number, will index into the list of palettes of appropriate
 #'   type. Default palette is `"Dark2"`.
-#' @param point.jitter.width Numeric specifying the degree of jitter in `x`
-#'   direction. Defaults to `40%` of the resolution of the data.
-#' @param point.jitter.height Numeric specifying the degree of jitter in `y`
-#'   direction. Defaults to `0.1`.
-#' @param point.dodge.width Numeric specifying the amount to dodge in the `x`
-#'   direction. Defaults to `0.60`.
+#' @param point.args A list of additional aesthetic arguments to be passed to
+#'   the `geom_point` displaying the raw data.
+#' @param violin.args A list of additional aesthetic arguments to be passed to
+#'   the `geom_violin`.
 #' @param ggplot.component A `ggplot` component to be added to the plot prepared
 #'   by `ggstatsplot`. This argument is primarily helpful for `grouped_` variant
 #'   of the current function. Default is `NULL`. The argument should be entered
-#'   as a function. If the given function has an argument `axes.range.restrict`
-#'   and if it has been set to `TRUE`, the added `ggplot` component *might* not
-#'   work as expected.
-#' @param axes.range.restrict Logical that decides whether to restrict the axes
-#'   values ranges to `min` and `max` values of the axes variables (Default:
-#'   `FALSE`), only relevant for functions where axes variables are of numeric
-#'   type.
-#' @param sort If `"ascending"` (default), `x`-axis variable factor levels will
-#'   be sorted based on increasing values of `y`-axis variable. If
-#'   `"descending"`, the opposite. If `"none"`, no sorting will happen.
-#' @param sort.fun The function used to sort (default: `mean`).
+#'   as a function.
 #' @param package Name of package from which the palette is desired as string
 #' or symbol.
 #' @param palette Name of palette as string or symbol.
 #' @param direction Either `1` or `-1`. If `-1` the palette will be reversed.
-#' @param return Character that describes what is to be returned: can be
+#' @param output Character that describes what is to be returned: can be
 #'   `"plot"` (default) or `"subtitle"` or `"caption"`. Setting this to
 #'   `"subtitle"` will return the expression containing statistical results. If
 #'   you have set `results.subtitle = FALSE`, then this will return a `NULL`.
 #'   Setting this to `"caption"` will return the expression containing details
 #'   about Bayes Factor analysis, but valid only when `type = "parametric"` and
 #'   `bf.message = TRUE`, otherwise this will return a `NULL`.
+#' @param ... Currently ignored.
 #' @inheritParams theme_ggstatsplot
+#' @param mean.point.args,mean.label.args A list of additional aesthetic
+#'   arguments to be passed to `ggplot2::geom_point` and
+#'   `ggrepel::geom_label_repel` geoms involved mean value plotting.
 #' @inheritParams statsExpressions::expr_anova_parametric
 #' @inheritParams statsExpressions::expr_t_parametric
 #' @inheritParams statsExpressions::expr_t_onesample
@@ -122,14 +109,14 @@
 #'
 #' @importFrom dplyr select group_by arrange mutate mutate_at mutate_if
 #' @importFrom ggrepel geom_label_repel
-#' @importFrom stats na.omit t.test oneway.test
+#' @importFrom stats t.test oneway.test
 #' @importFrom rlang enquo quo_name as_name !! as_string
 #' @importFrom ggrepel geom_label_repel
-#' @importFrom crayon blue green red yellow
 #' @importFrom paletteer scale_color_paletteer_d scale_fill_paletteer_d
 #' @importFrom ggsignif geom_signif
 #' @importFrom statsExpressions bf_ttest bf_oneway_anova
 #' @importFrom pairwiseComparisons pairwise_comparisons
+#' @importFrom ipmisc outlier_df
 #'
 #' @seealso \code{\link{grouped_ggbetweenstats}}, \code{\link{ggwithinstats}},
 #'  \code{\link{grouped_ggwithinstats}}
@@ -223,42 +210,42 @@ ggbetweenstats <- function(data,
                            conf.level = 0.95,
                            nboot = 100,
                            tr = 0.1,
-                           sort = "none",
-                           sort.fun = mean,
-                           axes.range.restrict = FALSE,
-                           mean.label.size = 3,
-                           mean.label.fontface = "bold",
-                           mean.label.color = "black",
+                           mean.plotting = TRUE,
+                           mean.ci = FALSE,
+                           mean.point.args = list(size = 5, color = "darkred"),
+                           mean.label.args = list(size = 3),
                            notch = FALSE,
                            notchwidth = 0.5,
                            linetype = "solid",
                            outlier.tagging = FALSE,
-                           outlier.shape = 19,
                            outlier.label = NULL,
-                           outlier.label.color = "black",
-                           outlier.color = "black",
                            outlier.coef = 1.5,
-                           mean.plotting = TRUE,
-                           mean.ci = FALSE,
-                           mean.size = 5,
-                           mean.color = "darkred",
-                           point.jitter.width = NULL,
-                           point.jitter.height = 0,
-                           point.dodge.width = 0.60,
+                           outlier.shape = 19,
+                           outlier.color = "black",
+                           outlier.label.args = list(size = 3),
+                           outlier.point.args = list(),
+                           point.args = list(
+                             position = ggplot2::position_jitterdodge(dodge.width = 0.60),
+                             alpha = 0.4,
+                             size = 3,
+                             stroke = 0
+                           ),
+                           violin.args = list(width = 0.5, alpha = 0.2),
                            ggtheme = ggplot2::theme_bw(),
                            ggstatsplot.layer = TRUE,
                            package = "RColorBrewer",
                            palette = "Dark2",
                            direction = 1,
                            ggplot.component = NULL,
-                           return = "plot",
-                           messages = TRUE) {
+                           output = "plot",
+                           messages = TRUE,
+                           ...) {
 
   # convert entered stats type to a standard notation
   type <- stats_type_switch(type)
 
   # no pairwise comparisons are available for Bayesian t-tests
-  if (type == "bayes" && isTRUE(pairwise.comparisons)) pairwise.comparisons <- FALSE
+  if (type == "bayes") pairwise.comparisons <- FALSE
 
   # ------------------------------ variable names ----------------------------
 
@@ -280,7 +267,7 @@ ggbetweenstats <- function(data,
     dplyr::select(.data = ., {{ x }}, {{ y }}, outlier.label = {{ outlier.label }}) %>%
     tidyr::drop_na(data = .) %>%
     dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    tibble::as_tibble(x = .)
+    as_tibble(x = .)
 
   # if outlier.label column is not present, just use the values from `y` column
   if (rlang::quo_is_null(rlang::enquo(outlier.label))) {
@@ -289,7 +276,7 @@ ggbetweenstats <- function(data,
 
   # add a logical column indicating whether a point is or is not an outlier
   data %<>%
-    outlier_df(
+    ipmisc::outlier_df(
       data = .,
       x = {{ x }},
       y = {{ y }},
@@ -301,67 +288,89 @@ ggbetweenstats <- function(data,
   # independent variables
   test <- ifelse(nlevels(data %>% dplyr::pull({{ x }}))[[1]] < 3, "t", "anova")
 
-  # --------------------------------- sorting --------------------------------
+  # --------------------- subtitle/caption preparation ------------------------
 
-  # if sorting is happening
-  if (sort != "none") {
-    data %<>%
-      sort_xy(
-        data = .,
+  if (isTRUE(results.subtitle)) {
+    # preparing the Bayes factor message
+    if (type == "parametric" && isTRUE(bf.message)) {
+      caption <-
+        caption_function_switch(
+          test = test,
+          data = data,
+          x = rlang::as_string(x),
+          y = rlang::as_string(y),
+          bf.prior = bf.prior,
+          caption = caption,
+          paired = FALSE,
+          output = "caption",
+          k = k
+        )
+    }
+
+    # extracting the subtitle using the switch function
+    subtitle <-
+      subtitle_function_switch(
+        # switch based on
+        type = type,
+        test = test,
+        # arguments relevant for subtitle helper functions
+        data = data,
         x = {{ x }},
         y = {{ y }},
-        sort = sort,
-        sort.fun = sort.fun
+        paired = FALSE,
+        effsize.type = effsize.type,
+        partial = partial,
+        effsize.noncentral = effsize.noncentral,
+        var.equal = var.equal,
+        bf.prior = bf.prior,
+        tr = tr,
+        nboot = nboot,
+        conf.level = conf.level,
+        stat.title = stat.title,
+        k = k,
+        messages = messages
       )
+  } else {
+    test <- "none"
+  }
+
+  # quit early if only subtitle is needed
+  if (output %in% c("subtitle", "caption")) {
+    return(switch(
+      EXPR = output,
+      "subtitle" = subtitle,
+      "caption" = caption
+    ))
   }
 
   # -------------------------- basic plot -----------------------------------
 
-  # single component for creating geom_violin
-  ggbetweenstats_geom_violin <-
-    ggplot2::geom_violin(
-      width = 0.5,
-      alpha = 0.2,
-      fill = "white",
-      na.rm = TRUE
-    )
-
   # create the basic plot
+  # add only the points which are *not* outliers
   plot <-
     ggplot2::ggplot(data = data, mapping = ggplot2::aes(x = {{ x }}, y = {{ y }})) +
-    # add all points which are not outliers
-    ggplot2::geom_point(
+    rlang::exec(
+      .fn = ggplot2::geom_point,
       data = dplyr::filter(.data = data, !isanoutlier),
-      position = ggplot2::position_jitterdodge(
-        jitter.width = point.jitter.width,
-        dodge.width = point.dodge.width,
-        jitter.height = point.jitter.height
-      ),
-      alpha = 0.4,
-      size = 3,
-      stroke = 0,
       na.rm = TRUE,
-      ggplot2::aes(color = {{ x }})
+      ggplot2::aes(color = {{ x }}),
+      !!!point.args
     )
 
-  # decide how to plot outliers if it's desired
+  # if outliers are not being tagged, then add the points that were left out
   if (isFALSE(outlier.tagging)) {
     plot <- plot +
-      # add all outliers in using same method
-      ggplot2::geom_point(
+      rlang::exec(
+        .fn = ggplot2::geom_point,
         data = dplyr::filter(.data = data, isanoutlier),
-        position = ggplot2::position_jitterdodge(
-          jitter.width = point.jitter.width,
-          dodge.width = point.dodge.width,
-          jitter.height = point.jitter.height
-        ),
-        alpha = 0.4,
-        size = 3,
-        stroke = 0,
         na.rm = TRUE,
-        ggplot2::aes(color = {{ x }})
+        ggplot2::aes(color = {{ x }}),
+        !!!point.args
       )
-  } else {
+  }
+
+  # if outlier tagging is happening, decide how those points should be displayed
+  if (isTRUE(outlier.tagging)) {
     if (plot.type == "violin") {
       plot <- plot +
         # add all outliers in
@@ -410,57 +419,17 @@ ggbetweenstats <- function(data,
           na.rm = TRUE
         )
     }
-    if (plot.type == "boxviolin") {
-      plot <- plot + ggbetweenstats_geom_violin
-    }
-  } else if (plot.type == "violin") {
-    plot <- plot + ggbetweenstats_geom_violin
   }
 
-  # --------------------- subtitle/caption preparation ------------------------
-
-  if (isTRUE(results.subtitle)) {
-    # preparing the Bayes factor message
-    if (type == "parametric" && isTRUE(bf.message)) {
-      caption <-
-        caption_function_switch(
-          test = test,
-          data = data,
-          x = rlang::as_string(x),
-          y = rlang::as_string(y),
-          bf.prior = bf.prior,
-          caption = caption,
-          paired = FALSE,
-          output = "caption",
-          k = k
-        )
-    }
-
-    # extracting the subtitle using the switch function
-    subtitle <-
-      subtitle_function_switch(
-        # switch based on
-        type = type,
-        test = test,
-        # arguments relevant for subtitle helper functions
-        data = data,
-        x = {{ x }},
-        y = {{ y }},
-        paired = FALSE,
-        effsize.type = effsize.type,
-        partial = partial,
-        effsize.noncentral = effsize.noncentral,
-        var.equal = var.equal,
-        bf.prior = bf.prior,
-        tr = tr,
-        nboot = nboot,
-        conf.level = conf.level,
-        stat.title = stat.title,
-        k = k,
-        messages = messages
+  # add violin geom
+  if (plot.type %in% c("violin", "boxviolin")) {
+    plot <- plot +
+      rlang::exec(
+        .fn = ggplot2::geom_violin,
+        fill = "white",
+        na.rm = TRUE,
+        !!!violin.args
       )
-  } else {
-    test <- "none"
   }
 
   # ---------------------------- outlier tagging -----------------------------
@@ -470,21 +439,17 @@ ggbetweenstats <- function(data,
   # already created.
 
   if (isTRUE(outlier.tagging)) {
-    # applying the labels to tagged outliers with ggrepel
+    # applying the labels to tagged outliers with `ggrepel`
     plot <- plot +
-      ggrepel::geom_label_repel(
-        data = dplyr::filter(.data = data, isanoutlier) %>%
-          dplyr::select(.data = ., -outlier),
+      rlang::exec(
+        .fn = ggrepel::geom_label_repel,
+        data = dplyr::filter(.data = data, isanoutlier),
         mapping = ggplot2::aes(x = {{ x }}, y = {{ y }}, label = outlier.label),
-        fontface = "bold",
-        color = outlier.label.color,
-        max.iter = 3e2,
-        box.padding = 0.35,
-        point.padding = 0.5,
-        segment.color = "black",
-        force = 2,
+        show.legend = FALSE,
+        min.segment.length = 0,
+        inherit.aes = FALSE,
         na.rm = TRUE,
-        seed = 123
+        !!!outlier.label.args
       )
   }
 
@@ -504,17 +469,16 @@ ggbetweenstats <- function(data,
 
   # add labels for mean values
   if (isTRUE(mean.plotting)) {
-    plot <- mean_ggrepel(
-      x = {{ x }},
-      y = {{ y }},
-      plot = plot,
-      mean.data = mean_dat,
-      mean.size = mean.size,
-      mean.color = mean.color,
-      mean.label.size = mean.label.size,
-      mean.label.fontface = mean.label.fontface,
-      mean.label.color = mean.label.color
-    )
+    plot <-
+      mean_ggrepel(
+        mean.data = mean_dat,
+        x = {{ x }},
+        y = {{ y }},
+        plot = plot,
+        mean.point.args = mean.point.args,
+        mean.label.args = mean.label.args,
+        inherit.aes = TRUE
+      )
   }
 
   # ----------------- sample size labels --------------------------------------
@@ -564,35 +528,22 @@ ggbetweenstats <- function(data,
   # ------------------------ annotations and themes -------------------------
 
   # specifying annotations and other aesthetic aspects for the plot
-  if (return == "plot") {
-    plot <-
-      aesthetic_addon(
-        plot = plot,
-        x = data %>% dplyr::pull({{ x }}),
-        xlab = xlab,
-        ylab = ylab,
-        title = title,
-        subtitle = subtitle,
-        caption = caption,
-        ggtheme = ggtheme,
-        ggstatsplot.layer = ggstatsplot.layer,
-        package = package,
-        palette = palette,
-        direction = direction,
-        ggplot.component = ggplot.component
-      )
-  }
-
-  # don't do scale restriction in case of post hoc comparisons
-  if (isTRUE(axes.range.restrict) && isFALSE(pairwise.comparisons)) {
-    # pull out vector for y-values
-    y_vec <- data %>% dplyr::pull({{ y }})
-
-    # restricting axes
-    plot <- plot +
-      ggplot2::coord_cartesian(ylim = c(min(y_vec), max(y_vec))) +
-      ggplot2::scale_y_continuous(limits = c(min(y_vec), max(y_vec)))
-  }
+  plot <-
+    aesthetic_addon(
+      plot = plot,
+      x = data %>% dplyr::pull({{ x }}),
+      xlab = xlab,
+      ylab = ylab,
+      title = title,
+      subtitle = subtitle,
+      caption = caption,
+      ggtheme = ggtheme,
+      ggstatsplot.layer = ggstatsplot.layer,
+      package = package,
+      palette = palette,
+      direction = direction,
+      ggplot.component = ggplot.component
+    )
 
   # --------------------- messages ------------------------------------------
 
@@ -601,8 +552,7 @@ ggbetweenstats <- function(data,
     normality_message(
       x = data %>% dplyr::pull({{ y }}),
       lab = ylab,
-      k = k,
-      output = "message"
+      k = k
     )
 
     # display homogeneity of variance test as a message
@@ -611,17 +561,10 @@ ggbetweenstats <- function(data,
       x = {{ x }},
       y = {{ y }},
       lab = xlab,
-      k = k,
-      output = "message"
+      k = k
     )
   }
 
   # return the final plot
-  return(switch(
-    EXPR = return,
-    "plot" = plot,
-    "subtitle" = subtitle,
-    "caption" = caption,
-    plot
-  ))
+  return(plot)
 }
