@@ -4,59 +4,56 @@
 #'   histograms/boxplots/density plots with statistical details added as a
 #'   subtitle.
 #'
+#' @param ... Currently ignored.
 #' @param label.var Variable to use for points labels. Can be entered either as
 #'   a character string (e.g., `"var1"`) or as a bare expression (e.g, `var1`).
 #' @param label.expression An expression evaluating to a logical vector that
 #'   determines the subset of data points to label. This argument can be entered
 #'   either as a character string (e.g., `"y < 4 & z < 20"`) or as a bare
 #'   expression (e.g., `y < 4 & z < 20`).
-#' @param line.color color for the regression line.
-#' @param line.size Size for the regression line.
-#' @param point.color,point.size,point.alpha Aesthetics specifying geom point
-#'   (defaults: `point.color = "black"`, `point.size = 3`,`point.alpha = 0.4`).
+#' @param point.label.args A list of additional aesthetic arguments to be passed
+#'   to `ggrepel::geom_label_repel` geom used to display the labels.
+#' @param smooth.line.args A list of additional aesthetic arguments to be passed
+#'   to `ggplot2::geom_smooth` geom used to display the regression line.
+#' @param point.args A list of additional aesthetic arguments to be passed
+#'   to `ggplot2::geom_point` geom used to display the raw data points.
 #' @param marginal Decides whether `ggExtra::ggMarginal()` plots will be
 #'   displayed; the default is `TRUE`.
+#' @param point.width.jitter,point.height.jitter Degree of jitter in `x` and `y`
+#'   direction, respectively. Defaults to `0` (0%) of the resolution of the
+#'   data. Note that the jitter should not be specified in the `point.args`
+#'   because this information will be passed to two different `geom`s: one
+#'   displaying the points and the other displaying the labels for these points.
 #' @param marginal.type Type of marginal distribution to be plotted on the axes
 #'   (`"histogram"`, `"boxplot"`, `"density"`, `"violin"`, `"densigram"`).
 #' @param marginal.size Integer describing the relative size of the marginal
 #'   plots compared to the main plot. A size of `5` means that the main plot is
 #'   5x wider and 5x taller than the marginal plots.
-#' @param margins Character describing along which margins to show the plots.
-#'   Any of the following arguments are accepted: `"both"`, `"x"`, `"y"`.
-#' @param package Name of package from which the palette is desired as string
-#' or symbol.
-#' @param direction Either `1` or `-1`. If `-1` the palette will be reversed.
-#' @param palette Name of palette as string or symbol.
 #' @param xfill,yfill Character describing color fill for `x` and `y` axes
-#'   marginal distributions (default: `"#009E73"` (for `x`) and `"#D55E00"` (for
-#'   `y`)). If set to `NULL`, manual specification of colors will be turned off
-#'   and 2 colors from the specified `palette` from `package` will be selected.
-#' @param xalpha,yalpha Numeric deciding transparency levels for the marginal
-#'   distributions. Any numbers from `0` (transparent) to `1` (opaque). The
-#'   default is `1` for both axes.
-#' @param xsize,ysize Size for the marginal distribution boundaries (Default:
-#'   `0.7`).
-#' @param centrality.para Decides *which* measure of central tendency (`"mean"`
+#'  marginal distributions (default: `"#009E73"` (for `x`) and `"#D55E00"` (for
+#'  `y`)). The same colors will also be used for the lines denoting centrality
+#'  parameters if `centrality.parameter` argument is set to `TRUE`. Note that
+#'  the defaults are colorblind-friendly.
+#' @param centrality.parameter Decides *which* measure of central tendency (`"mean"`
 #'   or `"median"`) is to be displayed as vertical (for `x`) and horizontal (for
 #'   `y`) lines. Note that mean values corresponds to arithmetic mean and not
 #'   geometric mean.
-#' @param point.width.jitter,point.height.jitter Degree of jitter in `x` and `y`
-#'   direction, respectively. Defaults to `0` (0%) of the resolution of the
-#'   data.
+#' @param vline.args,hline.args A list of additional aesthetic arguments to be
+#'   passed to `ggplot2::geom_vline` and `ggplot2::geom_hline` geoms used to
+#'   display the centrality parameter labels on vertical and horizontal lines.
 #' @inheritParams statsExpressions::expr_corr_test
 #' @inheritParams ggplot2::geom_smooth
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams ggbetweenstats
+#' @inheritParams ggExtra::ggMarginal
+#' @inheritParams gghistostats
 #'
 #' @import ggplot2
 #'
-#' @importFrom dplyr select group_by summarize n arrange if_else desc
-#' @importFrom dplyr mutate mutate_at mutate_if
-#' @importFrom rlang !! enquo quo_name parse_expr ensym as_name enexpr
-#' @importFrom ggExtra ggMarginal
-#' @importFrom stats cor.test
+#' @importFrom dplyr filter pull
+#' @importFrom rlang !! enquo quo_name parse_expr ensym as_name enexpr exec !!!
 #' @importFrom ggrepel geom_label_repel
-#' @importFrom tibble as_tibble
+#' @importFrom ggExtra ggMarginal
 #' @importFrom statsExpressions expr_corr_test bf_corr_test
 #'
 #' @seealso \code{\link{grouped_ggscatterstats}}, \code{\link{ggcorrmat}},
@@ -75,9 +72,10 @@
 #' \donttest{
 #' # to get reproducible results from bootstrapping
 #' set.seed(123)
+#' library(ggstatsplot)
 #'
 #' # creating dataframe with rownames converted to a new column
-#' mtcars_new <- tibble::as_tibble(mtcars, rownames = "car")
+#' mtcars_new <- as_tibble(mtcars, rownames = "car")
 #'
 #' # simple function call with the defaults
 #' ggstatsplot::ggscatterstats(
@@ -87,9 +85,7 @@
 #'   type = "np",
 #'   label.var = car,
 #'   label.expression = wt < 4 & mpg < 20,
-#'   axes.range.restrict = TRUE,
-#'   centrality.para = "median",
-#'   xfill = NULL
+#'   centrality.parameter = "median"
 #' )
 #' }
 #' @export
@@ -98,52 +94,51 @@
 ggscatterstats <- function(data,
                            x,
                            y,
-                           type = "pearson",
+                           type = "parametric",
                            conf.level = 0.95,
                            bf.prior = 0.707,
                            bf.message = TRUE,
                            label.var = NULL,
                            label.expression = NULL,
-                           xlab = NULL,
-                           ylab = NULL,
+                           point.label.args = list(size = 3),
+                           formula = y ~ x,
+                           smooth.line.args = list(size = 1.5, color = "blue"),
                            method = "lm",
                            method.args = list(),
-                           formula = y ~ x,
-                           point.color = "black",
-                           point.size = 3,
-                           point.alpha = 0.4,
+                           point.args = list(size = 3, alpha = 0.4),
                            point.width.jitter = 0,
                            point.height.jitter = 0,
-                           line.size = 1.5,
-                           line.color = "blue",
                            marginal = TRUE,
                            marginal.type = "histogram",
+                           margins = "both",
                            marginal.size = 5,
-                           margins = c("both", "x", "y"),
-                           package = "wesanderson",
-                           palette = "Royal1",
-                           direction = 1,
                            xfill = "#009E73",
                            yfill = "#D55E00",
-                           xalpha = 1,
-                           yalpha = 1,
-                           xsize = 0.7,
-                           ysize = 0.7,
-                           centrality.para = NULL,
+                           xparams = list(fill = xfill),
+                           yparams = list(fill = yfill),
+                           centrality.parameter = "none",
+                           centrality.label.args = list(size = 3),
+                           vline.args = list(color = xfill, size = 1, linetype = "dashed"),
+                           hline.args = list(color = yfill, size = 1, linetype = "dashed"),
                            results.subtitle = TRUE,
                            stat.title = NULL,
+                           xlab = NULL,
+                           ylab = NULL,
                            title = NULL,
                            subtitle = NULL,
                            caption = NULL,
                            nboot = 100,
                            beta = 0.1,
                            k = 2,
-                           axes.range.restrict = FALSE,
                            ggtheme = ggplot2::theme_bw(),
                            ggstatsplot.layer = TRUE,
                            ggplot.component = NULL,
-                           return = "plot",
-                           messages = TRUE) {
+                           output = "plot",
+                           messages = TRUE,
+                           ...) {
+
+  # convert entered stats type to a standard notation
+  type <- stats_type_switch(type)
 
   #---------------------- variable names --------------------------------
 
@@ -158,28 +153,30 @@ ggscatterstats <- function(data,
 
   #----------------------- linear model check ----------------------------
 
-  # subtitle statistics is valid only for linear models, so turn off the
-  # analysis if the model is not linear
-  # `method` argument can be a string (`"gam"`) or function (`MASS::rlm`)
-  method_ch <- paste(deparse(method), collapse = "")
+  if (isTRUE(results.subtitle)) {
+    # subtitle statistics is valid only for linear models, so turn off the
+    # analysis if the model is not linear
+    # `method` argument can be a string (`"gam"`) or function (`MASS::rlm`)
+    method_ch <- paste(deparse(method), collapse = "")
 
-  # check the formula and the method
-  if (as.character(deparse(formula)) != "y ~ x" ||
-    if (class(method) == "function") {
-      method_ch != paste(deparse(lm), collapse = "")
-    } else {
-      method != "lm"
-    }) {
-    # turn off the analysis
-    results.subtitle <- FALSE
+    # check the formula and the method
+    if (as.character(deparse(formula)) != "y ~ x" ||
+      if (class(method) == "function") {
+        method_ch != paste(deparse(lm), collapse = "")
+      } else {
+        method != "lm"
+      }) {
+      # tell the user
+      message(cat(
+        ipmisc::red("Warning: "),
+        ipmisc::blue("The statistical analysis is available only for linear model\n"),
+        ipmisc::blue("(formula = y ~ x, method = 'lm'). Returning only the plot.\n"),
+        sep = ""
+      ))
 
-    # tell the user
-    message(cat(
-      crayon::red("Warning: "),
-      crayon::blue("The statistical analysis is available only for linear model\n"),
-      crayon::blue("(formula = y ~ x, method = 'lm'). Returning only the plot.\n"),
-      sep = ""
-    ))
+      # turn off the analysis
+      results.subtitle <- FALSE
+    }
   }
 
   #----------------------- dataframe ---------------------------------------
@@ -187,41 +184,7 @@ ggscatterstats <- function(data,
   # preparing the dataframe
   data %<>%
     dplyr::filter(.data = ., !is.na({{ x }}), !is.na({{ y }})) %>%
-    tibble::as_tibble(.)
-
-  #---------------------------- user expression -------------------------
-
-  # check labeling variable has been entered
-  if (!rlang::quo_is_null(rlang::enquo(label.var))) {
-    point.labelling <- TRUE
-
-    # is expression provided?
-    if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
-      expression.present <- TRUE
-    } else {
-      expression.present <- FALSE
-    }
-
-    # creating a new dataframe for showing labels
-    if (isTRUE(expression.present)) {
-      if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
-        label.expression <- rlang::enexpr(label.expression)
-      }
-
-      # testing for whether we received bare or quoted
-      if (typeof(label.expression) == "language") {
-        # unquoted case
-        label_data <- dplyr::filter(.data = data, !!label.expression)
-      } else {
-        # quoted case
-        label_data <- dplyr::filter(.data = data, !!rlang::parse_expr(label.expression))
-      }
-    } else {
-      label_data <- data
-    }
-  } else {
-    point.labelling <- FALSE
-  }
+    as_tibble(.)
 
   #----------------------- creating results subtitle ------------------------
 
@@ -257,12 +220,54 @@ ggscatterstats <- function(data,
     }
 
     # if bayes factor message needs to be displayed
-    if (type %in% c("pearson", "parametric", "p") && isTRUE(bf.message)) {
-      caption <- bf.caption.text
-    }
+    if (type == "parametric" && isTRUE(bf.message)) caption <- bf.caption.text
   }
 
-  #--------------------------------- basic plot ---------------------------
+  # quit early if only subtitle is needed
+  if (output %in% c("subtitle", "caption")) {
+    return(switch(
+      EXPR = output,
+      "subtitle" = subtitle,
+      "caption" = caption
+    ))
+  }
+
+
+  #---------------------------- user expression -------------------------
+
+  # check labeling variable has been entered
+  if (!rlang::quo_is_null(rlang::enquo(label.var))) {
+    point.labelling <- TRUE
+
+    # is expression provided?
+    if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
+      expression.present <- TRUE
+    } else {
+      expression.present <- FALSE
+    }
+
+    # creating a new dataframe for showing labels
+    if (isTRUE(expression.present)) {
+      if (!rlang::quo_is_null(rlang::enquo(label.expression))) {
+        label.expression <- rlang::enexpr(label.expression)
+      }
+
+      # testing for whether we received bare or quoted
+      if (typeof(label.expression) == "language") {
+        # unquoted case
+        label_data <- dplyr::filter(.data = data, !!label.expression)
+      } else {
+        # quoted case
+        label_data <- dplyr::filter(.data = data, !!rlang::parse_expr(label.expression))
+      }
+    } else {
+      label_data <- data
+    }
+  } else {
+    point.labelling <- FALSE
+  }
+
+  # --------------------------------- basic plot ---------------------------
 
   # creating jittered positions
   pos <- ggplot2::position_jitter(
@@ -270,74 +275,40 @@ ggscatterstats <- function(data,
     height = point.height.jitter
   )
 
-  # if user has not specified colors, then use a color palette
-  if (is.null(xfill) || is.null(yfill)) {
-    colors <-
-      paletteer::paletteer_d(
-        palette = paste0(package, "::", palette),
-        n = 2,
-        direction = direction,
-        type = "discrete"
-      )
-
-    # assigning selected colors
-    xfill <- colors[1]
-    yfill <- colors[2]
-  }
-
   # preparing the scatterplot
   plot <-
     ggplot2::ggplot(data = data, mapping = ggplot2::aes(x = {{ x }}, y = {{ y }})) +
-    ggplot2::geom_point(
-      color = point.color,
-      size = point.size,
-      alpha = point.alpha,
+    rlang::exec(
+      .fn = ggplot2::geom_point,
       stroke = 0,
       position = pos,
-      na.rm = TRUE
+      na.rm = TRUE,
+      !!!point.args
     ) +
-    ggplot2::geom_smooth(
+    rlang::exec(
+      .fn = ggplot2::geom_smooth,
       method = method,
       method.args = method.args,
       formula = formula,
-      se = TRUE,
-      size = line.size,
-      color = line.color,
+      level = conf.level,
       na.rm = TRUE,
-      level = conf.level
-    ) +
-    ggstatsplot::theme_ggstatsplot(
-      ggtheme = ggtheme,
-      ggstatsplot.layer = ggstatsplot.layer
-    ) +
-    ggplot2::labs(
-      x = xlab,
-      y = ylab,
-      title = title,
-      subtitle = subtitle,
-      caption = caption
+      !!!smooth.line.args
     )
 
   #----------------------- adding centrality parameters --------------------
 
   # computing summary statistics needed for displaying labels
-  x_mean <- mean(x = data %>% dplyr::pull({{ x }}), na.rm = TRUE)
-  x_median <- median(x = data %>% dplyr::pull({{ x }}), na.rm = TRUE)
-  y_mean <- mean(x = data %>% dplyr::pull({{ y }}), na.rm = TRUE)
-  y_median <- median(x = data %>% dplyr::pull({{ y }}), na.rm = TRUE)
-  x_label_pos <- median(
-    x = ggplot2::layer_scales(plot)$x$range$range,
-    na.rm = TRUE
-  )
-  y_label_pos <- median(
-    x = ggplot2::layer_scales(plot)$y$range$range,
-    na.rm = TRUE
-  )
+  x_mean <- mean(data %>% dplyr::pull({{ x }}), na.rm = TRUE)
+  x_median <- median(data %>% dplyr::pull({{ x }}), na.rm = TRUE)
+  y_mean <- mean(data %>% dplyr::pull({{ y }}), na.rm = TRUE)
+  y_median <- median(data %>% dplyr::pull({{ y }}), na.rm = TRUE)
+  x_label_pos <- median(ggplot2::layer_scales(plot)$x$range$range, na.rm = TRUE)
+  y_label_pos <- median(ggplot2::layer_scales(plot)$y$range$range, na.rm = TRUE)
 
   # adding vertical and horizontal lines and attaching labels
-  if (!is.null(centrality.para) && !isFALSE(centrality.para)) {
+  if (centrality.parameter != "none") {
     # choosing the appropriate intercepts for the lines
-    if (centrality.para == "mean" || isTRUE(centrality.para)) {
+    if (centrality.parameter == "mean") {
       x.intercept <- x_mean
       y.intercept <- y_mean
       x.vline <- x_mean
@@ -358,20 +329,18 @@ ggscatterstats <- function(data,
     # adding lines
     plot <- plot +
       # vertical line
-      ggplot2::geom_vline(
+      rlang::exec(
+        .fn = ggplot2::geom_vline,
         xintercept = x.intercept,
-        linetype = "dashed",
-        color = xfill,
-        size = 1.0,
-        na.rm = TRUE
+        na.rm = TRUE,
+        !!!vline.args
       ) +
       # horizontal line
-      ggplot2::geom_hline(
+      rlang::exec(
+        .fn = ggplot2::geom_hline,
         yintercept = y.intercept,
-        linetype = "dashed",
-        color = yfill,
-        size = 1.0,
-        na.rm = TRUE
+        na.rm = TRUE,
+        !!!hline.args
       )
 
     # adding labels for *vertical* line
@@ -382,6 +351,7 @@ ggscatterstats <- function(data,
         y = y.vline,
         k = 2,
         color = xfill,
+        label.args = centrality.label.args,
         label.text = label.text,
         line.direction = "vline",
         jitter = 0.25
@@ -396,51 +366,45 @@ ggscatterstats <- function(data,
         k = 2,
         line.direction = "hline",
         color = yfill,
+        label.args = centrality.label.args,
         label.text = label.text,
         jitter = 0.25
       )
   }
 
-  #---------------------- range restriction -------------------------------
-
-  # forcing the plots to get cut off at min and max values of the variable
-  if (isTRUE(axes.range.restrict)) {
-    plot <- plot +
-      ggplot2::coord_cartesian(xlim = c(
-        min(data %>% dplyr::pull({{ x }}), na.rm = TRUE),
-        max(data %>% dplyr::pull({{ x }}), na.rm = TRUE)
-      )) +
-      ggplot2::coord_cartesian(ylim = c(
-        min(data %>% dplyr::pull({{ y }}), na.rm = TRUE),
-        max(data %>% dplyr::pull({{ y }}), na.rm = TRUE)
-      ))
-  }
-
   #-------------------- adding point labels --------------------------------
 
   # using geom_repel_label
   if (isTRUE(point.labelling)) {
     plot <- plot +
-      ggrepel::geom_label_repel(
+      rlang::exec(
+        .fn = ggrepel::geom_label_repel,
         data = label_data,
         mapping = ggplot2::aes(label = {{ label.var }}),
-        fontface = "bold",
-        color = "black",
-        max.iter = 3e2,
-        box.padding = 0.35,
-        point.padding = 0.5,
-        segment.color = "black",
-        force = 2,
+        show.legend = FALSE,
+        min.segment.length = 0,
+        na.rm = TRUE,
         position = pos,
-        na.rm = TRUE
+        !!!point.label.args
       )
   }
 
-  # ---------------- adding ggplot component ---------------------------------
+  #-------------------------- annotations -------------------------------------
 
-  # if any additional modification needs to be made to the plot
-  # this is primarily useful for grouped_ variant of this function
-  plot <- plot + ggplot.component
+  # annotations
+  plot <- plot +
+    ggstatsplot::theme_ggstatsplot(
+      ggtheme = ggtheme,
+      ggstatsplot.layer = ggstatsplot.layer
+    ) +
+    ggplot2::labs(
+      x = xlab,
+      y = ylab,
+      title = title,
+      subtitle = subtitle,
+      caption = caption
+    ) +
+    ggplot.component
 
   #------------------------- ggMarginal  ---------------------------------
 
@@ -453,18 +417,8 @@ ggscatterstats <- function(data,
         type = marginal.type,
         margins = margins,
         size = marginal.size,
-        xparams = list(
-          fill = xfill,
-          alpha = xalpha,
-          size = xsize,
-          col = "black"
-        ),
-        yparams = list(
-          fill = yfill,
-          alpha = yalpha,
-          size = ysize,
-          col = "black"
-        )
+        xparams = xparams,
+        yparams = yparams
       )
   }
 
@@ -473,19 +427,13 @@ ggscatterstats <- function(data,
   # display warning that this function doesn't produce a `ggplot2` object
   if (isTRUE(marginal) && isTRUE(messages)) {
     message(cat(
-      crayon::red("Warning: "),
-      crayon::blue("This plot can't be further modified with `ggplot2` functions.\n"),
-      crayon::blue("In case you want a `ggplot` object, set `marginal = FALSE`."),
+      ipmisc::red("Warning: "),
+      ipmisc::blue("This plot can't be further modified with `ggplot2` functions.\n"),
+      ipmisc::blue("In case you want a `ggplot` object, set `marginal = FALSE`."),
       sep = ""
     ))
   }
 
   # return the final plot
-  return(switch(
-    EXPR = return,
-    "plot" = plot,
-    "subtitle" = subtitle,
-    "caption" = caption,
-    plot
-  ))
+  return(plot)
 }
